use super::user;

pub trait DB : Send + Sync {
  fn new(&self, d: &user::Id) -> Result<(), String>;
  fn delete(&self, d: &user::Id) -> Result<(), String>;
  fn exists(&self, d: &user::Id) -> Result<bool, String>;

  fn get_profile(&self, id: &user::Id) -> Result<user::Profile, String>;
  fn set_profile(&self, id: &user::Id, d: user::Profile) -> Result<user::Profile, String>;
}

pub struct Null;
impl DB for Null {
  fn new(&self, d: &user::Id) -> Result<(), String> {
    Err("not implemented".to_owned())
  }
  fn delete(&self, d: &user::Id) -> Result<(), String> {
    Err("not implemented".to_owned())
  }
  fn exists(&self, d: &user::Id) -> Result<bool, String> {
    Err("not implemented".to_owned())
  }

  fn get_profile(&self, id: &user::Id) -> Result<user::Profile, String> {
    Err("not implemented".to_owned())
  }
  fn set_profile(&self, id: &user::Id, d: user::Profile) -> Result<user::Profile, String> {
    Err("not implemented".to_owned())
  }
}
